const CaesarDb = require('./caesar-loki-db');

module.exports = class StatsDb extends CaesarDb
{
    constructor ()
    {

        super ('caesar-stats.db', [
            {
                name: 'stats',
                options: {
                    unique: [ 'path' ]
                }
            },
            {
                name: 'metrics'
            },
            {
                name: 'daily-stats'
            }
        ]);

        this.removeDatabase();
    }

    getStats (clientId)
    {
        let stats = this.db.getCollection('stats');
        return stats.find({
            clientId: clientId,
            'count': { '$gt': 0 }
        });
    }

    getMetrics (path, numberOfResults = 10)
    {

        let metrics = this.db.getCollection('metrics');
        return metrics
            .chain()
            .find({
                path: path
            })
            .limit(numberOfResults)
            .simplesort('startTime', true)
            .data();
    }

    addMetric (path, metricData)
    {
        let metrics = this.db.getCollection('metrics');
        metrics.insert(
            Object.assign({path}, metricData)
        );
    }

    addStat (path, clientId) {
        let stats = this.db.getCollection('stats');
        let statObject = {
            clientId,
            path
        };

        let s = stats.findOne(statObject);
        if(s)
        {
            let count = s.count + 1;
            stats.update(Object.assign( s, {count}));
        }else{
            stats.insert(Object.assign( statObject, {count: 1}));
        }
    }

    addDailyStatCount ()
    {
        let dailyStats = this.db.getCollection('daily-stats');

        let dailyStatsObject = {
            date: new Date().toISOString().split('T')[0]
        };

        let today = dailyStats.findOne(dailyStatsObject);

        if(today) {
            let count = today.count + 1;
            dailyStats.update(Object.assign( today, {count}));
        } else {
            dailyStats.insert(Object.assign( dailyStatsObject, {count: 1} ));
        }
    }

    getTodayCount ()
    {
        let dailyStats = this.db.getCollection('daily-stats');

        let dailyStatsObject = {
            date: new Date().toISOString().split('T')[0]
        };

        let today = dailyStats.findOne(dailyStatsObject);

        return (!today) ? 0 : today.count;
    }
};
